﻿using System;
using System.Linq;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.ServiceModel.Activation;
using System.Collections.Generic;
using System.Text;
using People.Types.GeneratedTypes;
using People.Types.DTO;

namespace SilverlightApplication1.Web
{
    [ServiceContract(Namespace = "")]
    [AspNetCompatibilityRequirements(RequirementsMode = AspNetCompatibilityRequirementsMode.Allowed)]
    public class PeopleService
    {
        [OperationContract]
        public List<PersonViewModel> GetPeople()
        {
            List<PersonViewModel> personList = new List<PersonViewModel>();
            Person person = new Person();

            // Convert each Person to a PersonViewModel DTO.
            foreach (Person aPerson in person.ToList())
            {
                personList.Add(CreateDTOFromPerson(aPerson));
            }

            return personList;
        }

        [OperationContract]
        public bool SavePerson(PersonViewModel personViewModel)
        {
            // Save the new person.
            Person person = CreatePersonFromDTO(personViewModel);
            return person.Save();
        }

        [OperationContract]
        public bool DeletePerson(PersonViewModel personViewModel)
        {
            // Delete the selected person via the web service.
            Person person = CreatePersonFromDTO(personViewModel);
            return person.Delete();
        }

        #region DTO Helpers

        private Person CreatePersonFromDTO(PersonViewModel personViewModel)
        {
            // Helper function to convert a PersonViewModel DTO into a Person type.
            Person person = new Person();

            // Copy the person values from the DTO.
            Converter.ConvertToBusinessObject<Person>(person, personViewModel);

            // Copy the address values from the DTO.
            Converter.ConvertToBusinessObject<Address>(person.Address, personViewModel.Address);

            return person;
        }

        private PersonViewModel CreateDTOFromPerson(Person person)
        {
            // Helper function to convert a Person into a PersonViewModel DTO.
            PersonViewModel personViewModel = new PersonViewModel(person);

            // Copy the children.
            personViewModel.Address = new AddressViewModel(person.Address);

            return personViewModel;
        }

        #endregion
    }
}
